@@ -1,5 +1,5 @@
 package Games::Solitaire::Verify::Solution::ExpandMultiCardMoves;
-$Games::Solitaire::Verify::Solution::ExpandMultiCardMoves::VERSION = '0.2402';
+$Games::Solitaire::Verify::Solution::ExpandMultiCardMoves::VERSION = '0.2403';
 use warnings;
 use strict;
 use 5.014;
@@ -48,7 +48,7 @@ sub _out
 
     $self->_output_fh()->print($text);
 
-    return;
+    return ();
 }
 
 sub _out_line
@@ -83,7 +83,7 @@ sub _assign_read_new_state
     }
     $self->_st($new_state);
 
-    return;
+    return ();
 }
 
 sub _read_state
@@ -122,7 +122,7 @@ sub _read_state
     }
     $self->_out_line($line);
 
-    return;
+    return ();
 }
 
 sub _read_move
@@ -166,7 +166,7 @@ sub _read_move
         )
     );
 
-    return;
+    return ();
 }
 
 
@@ -237,14 +237,14 @@ sub _apply_move
 
         # Initialised to the null sub.
         my $output_state_promise = sub {
-            return;
+            return ();
         };
 
         my $past_first_output_state_promise = sub {
             $self->_out(
                 "\n" . $self->_st->to_string . "\n\n====================\n\n" );
 
-            return;
+            return ();
         };
 
         my $add_move = sub {
@@ -273,7 +273,7 @@ sub _apply_move
 
             $output_state_promise = $past_first_output_state_promise;
 
-            return;
+            return ();
         };
 
         my $move_using_freecells = sub {
@@ -295,7 +295,7 @@ sub _apply_move
                 );
             }
 
-            return;
+            return ();
         };
 
         my $recursive_move;
@@ -309,7 +309,7 @@ sub _apply_move
                 #    $num_cards_moved_at_each_stage[$depth] -
                 #    $num_cards_moved_at_each_stage[$depth-1]
                 #);
-                return;
+                return ();
             }
             else
             {
@@ -346,7 +346,7 @@ sub _apply_move
                     @running_empty_cols =
                         ( sort { $a <=> $b } @running_empty_cols, $s->{dest} );
                 }
-                return;
+                return ();
             }
         };
 
@@ -368,7 +368,7 @@ sub _apply_move
         }
     }
 
-    return;
+    return ();
 }
 
 
@@ -413,7 +413,7 @@ sub verify
         ref $err ? $err->rethrow : die $err;
     }
 
-    return;
+    return ();
 }
 
 1;    # End of Games::Solitaire::Verify::Solution::ExpandMultiCardMoves
@@ -432,7 +432,7 @@ moves.
 
 =head1 VERSION
 
-version 0.2402
+version 0.2403
 
 =head1 SYNOPSIS
 
