@@ -1,5 +1,5 @@
 package Games::Solitaire::Verify::VariantsMap;
-$Games::Solitaire::Verify::VariantsMap::VERSION = '0.2402';
+$Games::Solitaire::Verify::VariantsMap::VERSION = '0.2403';
 use strict;
 use warnings;
 
@@ -195,7 +195,7 @@ sub get_variant_by_id
 
     if ( !exists( $map->{$id} ) )
     {
-        return;
+        return undef;
     }
     else
     {
@@ -219,7 +219,7 @@ their parameters.
 
 =head1 VERSION
 
-version 0.2402
+version 0.2403
 
 =head1 FUNCTIONS
 
